@@ -20,23 +20,23 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include <glib.h>
-#include <glib/gi18n.h>
-#include <glib/gprintf.h>
-#include <glib-object.h>
-#include <gio/gio.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gepub.h>
-
 #include "gepub-thumbnailer.h"
 
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gepub.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <glib/gi18n.h>
+#include <glib/gprintf.h>
 
-static void gepub_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
-                                      GCancellable               *cancellable,
-                                      TumblerFileInfo            *info);
+
+static void
+gepub_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
+                          GCancellable *cancellable,
+                          TumblerFileInfo *info);
 
 
 
@@ -87,43 +87,29 @@ gepub_thumbnailer_init (GepubThumbnailer *thumbnailer)
 
 
 static GdkPixbuf *
-gepub_thumbnailer_create_from_mime (gchar             *mime_type,
-                                    GBytes            *content, 
-                                    TumblerThumbnail  *thumbnail,
-                                    GError           **error)
+gepub_thumbnailer_create_from_mime (gchar *mime_type,
+                                    GBytes *content,
+                                    TumblerThumbnail *thumbnail,
+                                    GError **error)
 {
   GdkPixbufLoader *loader;
-  GdkPixbuf       *pixbuf = NULL;
-  GError          *err = NULL;
+  GdkPixbuf *pixbuf = NULL;
 
   g_return_val_if_fail (TUMBLER_IS_THUMBNAIL (thumbnail), NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-  /* allow only some mime types */
-  if (g_strcmp0 (mime_type, "image/png") == 0 ||
-      g_strcmp0 (mime_type, "image/jpeg") == 0 ||
-      g_strcmp0 (mime_type, "image/gif") == 0)
+  loader = gdk_pixbuf_loader_new_with_mime_type (mime_type, error);
+  if (loader != NULL)
     {
-      loader = gdk_pixbuf_loader_new_with_mime_type (mime_type, &err);
       g_signal_connect (loader, "size-prepared",
                         G_CALLBACK (tumbler_util_size_prepared), thumbnail);
-      if (gdk_pixbuf_loader_write_bytes (loader, content, &err))
-        {
-          if (gdk_pixbuf_loader_close (loader, &err))
-            {
-              pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
-              if (pixbuf != NULL)
-                g_object_ref (G_OBJECT (pixbuf));
-            }
-        }
-      else
-        gdk_pixbuf_loader_close (loader, NULL);
+      if (gdk_pixbuf_loader_write_bytes (loader, content, error))
+        pixbuf = g_object_ref (gdk_pixbuf_loader_get_pixbuf (loader));
 
+      gdk_pixbuf_loader_close (loader, NULL);
       g_object_unref (loader);
-
-      if (err != NULL)
-        g_propagate_error (error, err);
     }
+
   return pixbuf;
 }
 
@@ -131,19 +117,19 @@ gepub_thumbnailer_create_from_mime (gchar             *mime_type,
 
 static void
 gepub_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
-                          GCancellable               *cancellable,
-                          TumblerFileInfo            *info)
+                          GCancellable *cancellable,
+                          TumblerFileInfo *info)
 {
-  TumblerImageData  data;
+  TumblerImageData data;
   TumblerThumbnail *thumbnail;
-  const gchar      *uri;
-  GFile            *file;
-  GError           *error = NULL;
-  GdkPixbuf        *pixbuf = NULL;
-  GepubDoc         *doc;
-  gchar            *cover;
-  gchar            *cover_mime;
-  GBytes           *content;
+  const gchar *uri;
+  GFile *file;
+  GError *error = NULL;
+  GdkPixbuf *pixbuf = NULL;
+  GepubDoc *doc;
+  gchar *cover;
+  gchar *cover_mime;
+  GBytes *content;
 
   g_return_if_fail (GEPUB_IS_THUMBNAILER (thumbnailer));
   g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
@@ -157,7 +143,7 @@ gepub_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   file = g_file_new_for_uri (uri);
   g_debug ("Handling URI '%s'", uri);
 
-  if (g_file_is_native (file))
+  if (g_file_peek_path (file) != NULL)
     {
       /* try to load the EPUB file */
       doc = gepub_doc_new (g_file_peek_path (file), &error);
@@ -229,8 +215,16 @@ gepub_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
       g_free (cover_mime);
       g_object_unref (doc);
       g_object_unref (thumbnail);
+      g_object_unref (file);
+    }
+  else
+    {
+      g_signal_emit_by_name (thumbnailer, "error", info,
+                             TUMBLER_ERROR, TUMBLER_ERROR_UNSUPPORTED,
+                             TUMBLER_ERROR_MESSAGE_LOCAL_ONLY);
+      g_object_unref (file);
+      return;
     }
-  g_object_unref (file);
 
   if (error != NULL)
     {
