@@ -11,11 +11,11 @@
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General 
- * Public License along with this library; if not, write to the 
+ * You should have received a copy of the GNU Library General
+ * Public License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
@@ -23,6 +23,8 @@
 #ifndef __GST_THUMBNAILER_PROVIDER_H__
 #define __GST_THUMBNAILER_PROVIDER_H__
 
+#include "tumbler/tumbler.h"
+
 #include <glib-object.h>
 
 G_BEGIN_DECLS
@@ -30,7 +32,8 @@ G_BEGIN_DECLS
 #define GST_TYPE_THUMBNAILER_PROVIDER (gst_thumbnailer_provider_get_type ())
 G_DECLARE_FINAL_TYPE (GstThumbnailerProvider, gst_thumbnailer_provider, GST, THUMBNAILER_PROVIDER, GObject)
 
-void gst_thumbnailer_provider_register (TumblerProviderPlugin *plugin);
+void
+gst_thumbnailer_provider_register (TumblerProviderPlugin *plugin);
 
 G_END_DECLS
 
