@@ -19,24 +19,23 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include <glib.h>
-#include <glib/gi18n.h>
-#include <glib-object.h>
-
-#include <tumbler/tumbler.h>
-
 #include "raw-thumbnailer-provider.h"
 #include "raw-thumbnailer.h"
 
+#include <glib/gi18n.h>
 
 
-G_MODULE_EXPORT void tumbler_plugin_initialize (TumblerProviderPlugin *plugin);
-G_MODULE_EXPORT void tumbler_plugin_shutdown   (void);
-G_MODULE_EXPORT void tumbler_plugin_get_types  (const GType          **types,
-                                                gint                  *n_types);
+
+G_MODULE_EXPORT void
+tumbler_plugin_initialize (TumblerProviderPlugin *plugin);
+G_MODULE_EXPORT void
+tumbler_plugin_shutdown (void);
+G_MODULE_EXPORT void
+tumbler_plugin_get_types (const GType **types,
+                          gint *n_types);
 
 
 
@@ -80,7 +79,7 @@ tumbler_plugin_shutdown (void)
 
 void
 tumbler_plugin_get_types (const GType **types,
-                          gint         *n_types)
+                          gint *n_types)
 {
   *types = type_list;
   *n_types = G_N_ELEMENTS (type_list);
