@@ -19,47 +19,51 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
+#include "xdg-cache-cache.h"
+#include "xdg-cache-thumbnail.h"
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib/gi18n.h>
+#include <glib/gprintf.h>
+#include <glib/gstdio.h>
+#include <math.h>
+#include <png.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
-
-#include <glib.h>
-#include <glib/gi18n.h>
-#include <glib/gstdio.h>
-#include <glib/gprintf.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
-
-#include <png.h>
-
-#include <tumbler/tumbler.h>
-
-#include <xdg-cache/xdg-cache-cache.h>
-#include <xdg-cache/xdg-cache-thumbnail.h>
 
 
 
-static void              xdg_cache_cache_iface_init         (TumblerCacheIface      *iface);
-static void              xdg_cache_cache_finalize           (GObject                *object);
-static TumblerThumbnail *xdg_cache_cache_get_thumbnail      (TumblerCache           *cache,
-                                                             const gchar            *uri,
-                                                             TumblerThumbnailFlavor *flavor);
-static void              xdg_cache_cache_cleanup            (TumblerCache           *cache,
-                                                             const gchar *const     *base_uris,
-                                                             gdouble                 since);
-static void              xdg_cache_cache_delete             (TumblerCache           *cache,
-                                                             const gchar *const     *uris);
-static void              xdg_cache_cache_copy               (TumblerCache           *cache,
-                                                             const gchar *const     *from_uris,
-                                                             const gchar *const     *to_uris);
-static void              xdg_cache_cache_move               (TumblerCache           *cache,
-                                                             const gchar *const     *from_uris,
-                                                             const gchar *const     *to_uris);
-static gboolean          xdg_cache_cache_is_thumbnail       (TumblerCache           *cache,
-                                                             const gchar            *uri);
-static GList            *xdg_cache_cache_get_flavors        (TumblerCache           *cache);
+static void
+xdg_cache_cache_iface_init (TumblerCacheIface *iface);
+static void
+xdg_cache_cache_finalize (GObject *object);
+static TumblerThumbnail *
+xdg_cache_cache_get_thumbnail (TumblerCache *cache,
+                               const gchar *uri,
+                               TumblerThumbnailFlavor *flavor);
+static void
+xdg_cache_cache_cleanup (TumblerCache *cache,
+                         const gchar *const *base_uris,
+                         gdouble since);
+static void
+xdg_cache_cache_delete (TumblerCache *cache,
+                        const gchar *const *uris);
+static void
+xdg_cache_cache_copy (TumblerCache *cache,
+                      const gchar *const *from_uris,
+                      const gchar *const *to_uris);
+static void
+xdg_cache_cache_move (TumblerCache *cache,
+                      const gchar *const *from_uris,
+                      const gchar *const *to_uris);
+static gboolean
+xdg_cache_cache_is_thumbnail (TumblerCache *cache,
+                              const gchar *uri);
+static GList *
+xdg_cache_cache_get_flavors (TumblerCache *cache);
 
 
 
@@ -67,7 +71,9 @@ struct _XDGCacheCache
 {
   GObject __parent__;
 
-  GList  *flavors;
+  GList *flavors;
+  GList *dirs;
+  GList *shared_suffixes;
 };
 
 
@@ -125,6 +131,7 @@ static void
 xdg_cache_cache_init (XDGCacheCache *cache)
 {
   TumblerThumbnailFlavor *flavor;
+  const gchar *cachedir = g_get_user_cache_dir ();
 
   flavor = tumbler_thumbnail_flavor_new_normal ();
   cache->flavors = g_list_prepend (cache->flavors, flavor);
@@ -137,6 +144,16 @@ xdg_cache_cache_init (XDGCacheCache *cache)
 
   flavor = tumbler_thumbnail_flavor_new_xx_large ();
   cache->flavors = g_list_prepend (cache->flavors, flavor);
+
+  for (GList *lp = cache->flavors; lp != NULL; lp = lp->next)
+    {
+      const gchar *dirname = tumbler_thumbnail_flavor_get_name (lp->data);
+      gchar *path = g_build_filename (cachedir, "thumbnails", dirname, NULL);
+      gchar *suffix = g_strconcat (G_DIR_SEPARATOR_S, ".sh_thumbnails", G_DIR_SEPARATOR_S, dirname, NULL);
+      cache->dirs = g_list_prepend (cache->dirs, g_file_new_for_path (path));
+      cache->shared_suffixes = g_list_prepend (cache->shared_suffixes, suffix);
+      g_free (path);
+    }
 }
 
 
@@ -147,6 +164,8 @@ xdg_cache_cache_finalize (GObject *object)
   XDGCacheCache *cache = XDG_CACHE_CACHE (object);
 
   g_list_free_full (cache->flavors, g_object_unref);
+  g_list_free_full (cache->dirs, g_object_unref);
+  g_list_free_full (cache->shared_suffixes, g_free);
 
   G_OBJECT_CLASS (xdg_cache_cache_parent_class)->finalize (object);
 }
@@ -154,8 +173,8 @@ xdg_cache_cache_finalize (GObject *object)
 
 
 static TumblerThumbnail *
-xdg_cache_cache_get_thumbnail (TumblerCache           *cache,
-                               const gchar            *uri,
+xdg_cache_cache_get_thumbnail (TumblerCache *cache,
+                               const gchar *uri,
                                TumblerThumbnailFlavor *flavor)
 {
   g_return_val_if_fail (XDG_CACHE_IS_CACHE (cache), NULL);
@@ -171,38 +190,38 @@ xdg_cache_cache_get_thumbnail (TumblerCache           *cache,
 
 
 static void
-xdg_cache_cache_cleanup (TumblerCache       *cache,
+xdg_cache_cache_cleanup (TumblerCache *cache,
                          const gchar *const *base_uris,
-                         gdouble             since)
+                         gdouble since)
 {
   XDGCacheCache *xdg_cache = XDG_CACHE_CACHE (cache);
-  const gchar   *file_basename;
-  gdouble        mtime;
-  GFile         *base_file;
-  GFile         *dummy_file;
-  GFile         *original_file;
-  GFile         *parent;
-  GList         *iter;
-  gchar         *dirname;
-  gchar         *filename;
-  gchar         *uri;
-  guint          n;
-  GDir          *dir;
+  const gchar *file_basename;
+  gdouble mtime;
+  GFile *base_file;
+  GFile *dummy_file;
+  GFile *original_file;
+  GFile *parent;
+  GList *iter;
+  gchar *dirname;
+  gchar *filename;
+  gchar *uri;
+  guint n;
+  GDir *dir;
 
   g_return_if_fail (XDG_CACHE_IS_CACHE (cache));
 
   /* iterate over all flavors */
   for (iter = xdg_cache->flavors; iter != NULL; iter = iter->next)
     {
-      /* compute the flavor directory filename */
-      dummy_file = xdg_cache_cache_get_file ("foo", iter->data);
-      parent = g_file_get_parent (dummy_file);
-      dirname = g_file_get_path (parent);
-      g_object_unref (parent);
-      g_object_unref (dummy_file);
-
       if (since != 0)
         {
+          /* compute the flavor directory filename */
+          dummy_file = xdg_cache_cache_get_file ("foo", iter->data);
+          parent = g_file_get_parent (dummy_file);
+          dirname = g_file_get_path (parent);
+          g_object_unref (parent);
+          g_object_unref (dummy_file);
+
           /* attempt to open the directory for reading */
           dir = g_dir_open (dirname, 0, NULL);
           if (dir != NULL)
@@ -227,8 +246,8 @@ xdg_cache_cache_cleanup (TumblerCache       *cache,
                         }
                       else
                         {
-                           /* create a GFile for the original URI. we need this for
-                            * reliably checking the ancestor/descendant relationship */
+                          /* create a GFile for the original URI. we need this for
+                           * reliably checking the ancestor/descendant relationship */
                           original_file = g_file_new_for_uri (uri);
 
                           for (n = 0; base_uris != NULL && base_uris[n] != NULL; ++n)
@@ -244,7 +263,7 @@ xdg_cache_cache_cleanup (TumblerCache       *cache,
                                 }
 
                               /* releas the base file */
-                              g_object_unref(base_file);
+                              g_object_unref (base_file);
                             }
 
                           /* release the original file */
@@ -276,12 +295,12 @@ xdg_cache_cache_cleanup (TumblerCache       *cache,
 
               filename = (gchar *) g_file_peek_path (base_file);
               if (g_file_test (filename, G_FILE_TEST_IS_REGULAR))
-              {
-                g_unlink (filename);
-              }
+                {
+                  g_unlink (filename);
+                }
 
               /* releas the base file */
-              g_object_unref(base_file);
+              g_object_unref (base_file);
             }
         }
     }
@@ -290,13 +309,13 @@ xdg_cache_cache_cleanup (TumblerCache       *cache,
 
 
 static void
-xdg_cache_cache_delete (TumblerCache       *cache,
+xdg_cache_cache_delete (TumblerCache *cache,
                         const gchar *const *uris)
 {
   XDGCacheCache *xdg_cache = XDG_CACHE_CACHE (cache);
-  GList         *iter;
-  GFile         *file;
-  gint           n;
+  GList *iter;
+  GFile *file;
+  gint n;
 
   g_return_if_fail (XDG_CACHE_IS_CACHE (cache));
   g_return_if_fail (uris != NULL);
@@ -315,19 +334,19 @@ xdg_cache_cache_delete (TumblerCache       *cache,
 
 
 static void
-xdg_cache_cache_copy_or_move_file (TumblerCache           *cache,
+xdg_cache_cache_copy_or_move_file (TumblerCache *cache,
                                    TumblerThumbnailFlavor *flavor,
-                                   gboolean                do_copy,
-                                   const gchar            *from_uri,
-                                   const gchar            *to_uri,
-                                   gdouble                 mtime)
+                                   gboolean do_copy,
+                                   const gchar *from_uri,
+                                   const gchar *to_uri,
+                                   gdouble mtime)
 {
-  GFile    *from_file;
-  GFile    *temp_file;
+  GFile *from_file;
+  GFile *temp_file;
   const gchar *temp_path;
   const gchar *dest_path;
-  gboolean  result;
-  GFile    *dest_file;
+  gboolean result;
+  GFile *dest_file;
 
   from_file = xdg_cache_cache_get_file (from_uri, flavor);
   temp_file = xdg_cache_cache_get_temp_file (to_uri, flavor);
@@ -376,27 +395,27 @@ xdg_cache_cache_copy_or_move_file (TumblerCache           *cache,
 
 
 static void
-xdg_cache_cache_copy_or_move (TumblerCache       *cache,
-                              gboolean            do_copy,
+xdg_cache_cache_copy_or_move (TumblerCache *cache,
+                              gboolean do_copy,
                               const gchar *const *from_uris,
                               const gchar *const *to_uris)
 {
   XDGCacheCache *xdg_cache = XDG_CACHE_CACHE (cache);
-  GFileInfo     *info;
-  gdouble        mtime;
-  GFile         *dest_source_file;
-  GList         *iter;
-  guint          n;
-  GFile         *dummy_file;
-  GFile         *parent;
-  gchar         *dirname;
-  GDir          *dir;
-  const gchar   *file_basename;
-  gchar         *filename;
-  gchar         *uri;
-  GFile         *original_file;
-  GFile         *base_file;
-  gchar         *to_uri;
+  GFileInfo *info;
+  gdouble mtime;
+  GFile *dest_source_file;
+  GList *iter;
+  guint n;
+  GFile *dummy_file;
+  GFile *parent;
+  gchar *dirname;
+  GDir *dir;
+  const gchar *file_basename;
+  gchar *filename;
+  gchar *uri;
+  GFile *original_file;
+  GFile *base_file;
+  gchar *to_uri;
 
   g_return_if_fail (XDG_CACHE_IS_CACHE (cache));
   g_return_if_fail (from_uris != NULL);
@@ -404,13 +423,13 @@ xdg_cache_cache_copy_or_move (TumblerCache       *cache,
 
   for (iter = xdg_cache->flavors; iter != NULL; iter = iter->next)
     {
-      for (n = 0; n < g_strv_length ((gchar **)from_uris); ++n)
+      for (n = 0; n < g_strv_length ((gchar **) from_uris); ++n)
         {
           dest_source_file = g_file_new_for_uri (to_uris[n]);
           info = g_file_query_info (dest_source_file,
                                     G_FILE_ATTRIBUTE_STANDARD_TYPE
-                                      "," G_FILE_ATTRIBUTE_TIME_MODIFIED
-                                      "," G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC,
+                                    "," G_FILE_ATTRIBUTE_TIME_MODIFIED
+                                    "," G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC,
                                     G_FILE_QUERY_INFO_NONE, NULL, NULL);
 
           if (info == NULL)
@@ -447,7 +466,7 @@ xdg_cache_cache_copy_or_move (TumblerCache       *cache,
                           && uri != NULL)
                         {
                           /* create a GFile for the original URI. we need this for
-                          * reliably checking the ancestor/descendant relationship */
+                           * reliably checking the ancestor/descendant relationship */
                           original_file = g_file_new_for_uri (uri);
 
                           /* check if we have a thumbnail that is located in the moved/copied folder */
@@ -476,7 +495,7 @@ xdg_cache_cache_copy_or_move (TumblerCache       *cache,
                       file_basename = g_dir_read_name (dir);
                     }
 
-                 g_dir_close (dir);
+                  g_dir_close (dir);
                 }
 
               g_free (dirname);
@@ -485,8 +504,7 @@ xdg_cache_cache_copy_or_move (TumblerCache       *cache,
           else
             {
               mtime = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_TIME_MODIFIED)
-                      + 1e-6 * g_file_info_get_attribute_uint32 (info,
-                                                                 G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC);
+                      + 1e-6 * g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC);
               xdg_cache_cache_copy_or_move_file (cache, iter->data, do_copy,
                                                  from_uris[n], to_uris[n],
                                                  mtime);
@@ -501,7 +519,7 @@ xdg_cache_cache_copy_or_move (TumblerCache       *cache,
 
 
 static void
-xdg_cache_cache_copy (TumblerCache       *cache,
+xdg_cache_cache_copy (TumblerCache *cache,
                       const gchar *const *from_uris,
                       const gchar *const *to_uris)
 {
@@ -510,9 +528,8 @@ xdg_cache_cache_copy (TumblerCache       *cache,
 
 
 
-
 static void
-xdg_cache_cache_move (TumblerCache       *cache,
+xdg_cache_cache_move (TumblerCache *cache,
                       const gchar *const *from_uris,
                       const gchar *const *to_uris)
 {
@@ -523,46 +540,44 @@ xdg_cache_cache_move (TumblerCache       *cache,
 
 static gboolean
 xdg_cache_cache_is_thumbnail (TumblerCache *cache,
-                              const gchar  *uri)
+                              const gchar *uri)
 {
   XDGCacheCache *xdg_cache = XDG_CACHE_CACHE (cache);
-  const gchar   *cachedir;
-  const gchar   *dirname;
-  gboolean       is_thumbnail = FALSE;
-  GList         *iter;
-  GFile         *flavor_dir;
-  GFile         *file;
-  gchar         *path;
-  gchar         *needle;
+  gboolean is_thumbnail = FALSE;
+  GFile *file;
+  gchar *uri_dir;
 
   g_return_val_if_fail (XDG_CACHE_IS_CACHE (cache), FALSE);
   g_return_val_if_fail (uri != NULL, FALSE);
 
-  for (iter = xdg_cache->flavors; !is_thumbnail && iter != NULL; iter = iter->next)
+  /* check if it is a thumbnail in local cache */
+  file = g_file_new_for_uri (uri);
+  for (GList *lp = xdg_cache->dirs; lp != NULL; lp = lp->next)
     {
-      cachedir = g_get_user_cache_dir ();
-      dirname = tumbler_thumbnail_flavor_get_name (iter->data);
-      path = g_build_filename (cachedir, "thumbnails", dirname, NULL);
-
-      flavor_dir = g_file_new_for_path (path);
-      file = g_file_new_for_uri (uri);
-
-      if (g_file_has_prefix (file, flavor_dir))
-        is_thumbnail = TRUE;
-
-      g_object_unref (file);
-      g_object_unref (flavor_dir);
-
-      g_free (path);
+      if (g_file_has_parent (file, lp->data))
+        {
+          is_thumbnail = TRUE;
+          break;
+        }
     }
+  g_object_unref (file);
 
   if (is_thumbnail)
     return TRUE;
 
   /* check if it is a thumbnail in a shared repository */
-  needle = g_strrstr (uri, "/.sh_thumbnails/");
+  uri_dir = g_path_get_dirname (uri);
+  for (GList *lp = xdg_cache->shared_suffixes; lp != NULL; lp = lp->next)
+    {
+      if (g_str_has_suffix (uri_dir, lp->data))
+        {
+          is_thumbnail = TRUE;
+          break;
+        }
+    }
+  g_free (uri_dir);
 
-  return needle != NULL;
+  return is_thumbnail;
 }
 
 
@@ -571,8 +586,8 @@ static GList *
 xdg_cache_cache_get_flavors (TumblerCache *cache)
 {
   XDGCacheCache *xdg_cache = XDG_CACHE_CACHE (cache);
-  GList         *flavors = NULL;
-  GList         *iter;
+  GList *flavors = NULL;
+  GList *iter;
 
   g_return_val_if_fail (XDG_CACHE_IS_CACHE (cache), NULL);
 
@@ -585,15 +600,15 @@ xdg_cache_cache_get_flavors (TumblerCache *cache)
 
 
 GFile *
-xdg_cache_cache_get_file (const gchar            *uri,
+xdg_cache_cache_get_file (const gchar *uri,
                           TumblerThumbnailFlavor *flavor)
 {
   const gchar *cachedir;
   const gchar *dirname;
-  GFile       *file;
-  gchar       *filename;
-  gchar       *md5_hash;
-  gchar       *path;
+  GFile *file;
+  gchar *filename;
+  gchar *md5_hash;
+  gchar *path;
 
   g_return_val_if_fail (uri != NULL && *uri != '\0', NULL);
   g_return_val_if_fail (TUMBLER_IS_THUMBNAIL_FLAVOR (flavor), NULL);
@@ -617,16 +632,16 @@ xdg_cache_cache_get_file (const gchar            *uri,
 
 
 GFile *
-xdg_cache_cache_get_temp_file (const gchar            *uri,
+xdg_cache_cache_get_temp_file (const gchar *uri,
                                TumblerThumbnailFlavor *flavor)
 {
   const gchar *cachedir;
   const gchar *dirname;
-  gint64       current_time;
-  GFile       *file;
-  gchar       *filename;
-  gchar       *md5_hash;
-  gchar       *path;
+  gint64 current_time;
+  GFile *file;
+  gchar *filename;
+  gchar *md5_hash;
+  gchar *path;
 
   g_return_val_if_fail (uri != NULL && *uri != '\0', NULL);
   g_return_val_if_fail (TUMBLER_IS_THUMBNAIL_FLAVOR (flavor), NULL);
@@ -656,20 +671,20 @@ xdg_cache_cache_get_temp_file (const gchar            *uri,
  * Check whether @uri is non-%NULL and @mtime is a valid time to determine
  * between the two. Will return %FALSE and set @error if the PNG was corrupt. */
 gboolean
-xdg_cache_cache_read_thumbnail_info (const gchar  *filename,
-                                     gchar       **uri,
-                                     gdouble      *mtime,
+xdg_cache_cache_read_thumbnail_info (const gchar *filename,
+                                     gchar **uri,
+                                     gdouble *mtime,
                                      GCancellable *cancellable,
-                                     GError      **error)
+                                     GError **error)
 {
   png_structp png_ptr;
-  png_infop   info_ptr;
-  png_textp   text_ptr;
-  gboolean    has_uri;
-  gboolean    has_mtime;
-  FILE       *png;
-  gint        num_text;
-  gint        i;
+  png_infop info_ptr;
+  png_textp text_ptr;
+  gboolean has_uri;
+  gboolean has_mtime;
+  FILE *png;
+  gint num_text;
+  gint i;
 
   g_return_val_if_fail (filename != NULL, FALSE);
   g_return_val_if_fail (uri != NULL, FALSE);
@@ -759,16 +774,16 @@ xdg_cache_cache_read_thumbnail_info (const gchar  *filename,
 
 
 gboolean
-xdg_cache_cache_write_thumbnail_info (const gchar  *filename,
-                                      const gchar  *uri,
-                                      gdouble       mtime,
+xdg_cache_cache_write_thumbnail_info (const gchar *filename,
+                                      const gchar *uri,
+                                      gdouble mtime,
                                       GCancellable *cancellable,
-                                      GError      **error)
+                                      GError **error)
 {
   GdkPixbuf *pixbuf;
-  GError    *err = NULL;
-  gchar     *mtime_str;
-  guint64    mtime_int = (guint64) mtime;
+  GError *err = NULL;
+  gchar *mtime_str;
+  guint64 mtime_int = (guint64) mtime;
 
   g_return_val_if_fail (filename != NULL, FALSE);
   g_return_val_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable), FALSE);
