@@ -2,30 +2,28 @@
 /*-
  * Copyright (c) 2011 Jannis Pohlmann <jannis@xfce.org>
  *
- * This program is free software; you can redistribute it and/or 
+ * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of 
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public 
- * License along with this program; if not, write to the Free 
+ * You should have received a copy of the GNU General Public
+ * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include <glib.h>
-
-#include <tumblerd/tumbler-component.h>
-#include <tumblerd/tumbler-lifecycle-manager.h>
+#include "tumbler-component.h"
+#include "tumbler-lifecycle-manager.h"
 
 
 
@@ -37,18 +35,21 @@ enum
 };
 
 
-#define get_instance_private(instance) ((TumblerComponentPrivate *) \
-  tumbler_component_get_instance_private (TUMBLER_COMPONENT (instance)))
+#define get_instance_private(instance) \
+  ((TumblerComponentPrivate *) tumbler_component_get_instance_private (TUMBLER_COMPONENT (instance)))
 
-static void tumbler_component_finalize     (GObject      *object);
-static void tumbler_component_get_property (GObject      *object,
-                                            guint         prop_id,
-                                            GValue       *value,
-                                            GParamSpec   *pspec);
-static void tumbler_component_set_property (GObject      *object,
-                                            guint         prop_id,
-                                            const GValue *value,
-                                            GParamSpec   *pspec);
+static void
+tumbler_component_finalize (GObject *object);
+static void
+tumbler_component_get_property (GObject *object,
+                                guint prop_id,
+                                GValue *value,
+                                GParamSpec *pspec);
+static void
+tumbler_component_set_property (GObject *object,
+                                guint prop_id,
+                                const GValue *value,
+                                GParamSpec *pspec);
 
 
 
@@ -72,7 +73,7 @@ tumbler_component_class_init (TumblerComponentClass *klass)
   tumbler_component_parent_class = g_type_class_peek_parent (klass);
 
   gobject_class = G_OBJECT_CLASS (klass);
-  gobject_class->finalize = tumbler_component_finalize; 
+  gobject_class->finalize = tumbler_component_finalize;
   gobject_class->get_property = tumbler_component_get_property;
   gobject_class->set_property = tumbler_component_set_property;
 
@@ -82,8 +83,7 @@ tumbler_component_class_init (TumblerComponentClass *klass)
                                                         "lifecycle-manager",
                                                         "lifecycle-manager",
                                                         TUMBLER_TYPE_LIFECYCLE_MANAGER,
-                                                        G_PARAM_READWRITE |
-                                                        G_PARAM_CONSTRUCT));
+                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
 
 
@@ -108,9 +108,9 @@ tumbler_component_finalize (GObject *object)
 
 
 static void
-tumbler_component_get_property (GObject    *object,
-                                guint       prop_id,
-                                GValue     *value,
+tumbler_component_get_property (GObject *object,
+                                guint prop_id,
+                                GValue *value,
                                 GParamSpec *pspec)
 {
   TumblerComponentPrivate *priv = get_instance_private (object);
@@ -129,17 +129,17 @@ tumbler_component_get_property (GObject    *object,
 
 
 static void
-tumbler_component_set_property (GObject      *object,
-                                guint         prop_id,
+tumbler_component_set_property (GObject *object,
+                                guint prop_id,
                                 const GValue *value,
-                                GParamSpec   *pspec)
+                                GParamSpec *pspec)
 {
   TumblerComponentPrivate *priv = get_instance_private (object);
 
   switch (prop_id)
     {
     case PROP_LIFECYCLE_MANAGER:
-      priv->lifecycle_manager = g_value_dup_object(value);
+      priv->lifecycle_manager = g_value_dup_object (value);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -151,7 +151,7 @@ tumbler_component_set_property (GObject      *object,
 
 gboolean
 tumbler_component_keep_alive (TumblerComponent *component,
-                              GError          **error)
+                              GError **error)
 {
   g_return_val_if_fail (TUMBLER_IS_COMPONENT (component), FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
