@@ -2,47 +2,44 @@
 /*-
  * Copyright (c) 2009-2011 Jannis Pohlmann <jannis@xfce.org>
  * Copyright (c) 2015      Ali Abdallah    <ali@xfce.org>
- * 
- * This program is free software; you can redistribute it and/or 
+ *
+ * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of 
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public 
- * License along with this program; if not, write to the Free 
+ * You should have received a copy of the GNU General Public
+ * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include <glib.h>
-#include <glib/gi18n.h>
-#include <glib-object.h>
+#include "tumbler-group-scheduler.h"
+#include "tumbler-lifo-scheduler.h"
+#include "tumbler-scheduler.h"
+#include "tumbler-service-gdbus.h"
+#include "tumbler-service.h"
+#include "tumbler-utils.h"
+
+#include "tumbler/tumbler.h"
 
 #include <gio/gio.h>
-
-#include <tumbler/tumbler.h>
-
-#include <tumblerd/tumbler-scheduler.h>
-#include <tumblerd/tumbler-service.h>
-#include <tumblerd/tumbler-lifo-scheduler.h>
-#include <tumblerd/tumbler-group-scheduler.h>
-#include <tumblerd/tumbler-utils.h>
-#include <tumblerd/tumbler-service-gdbus.h>
+#include <glib-object.h>
+#include <glib/gi18n.h>
 
 
-#define THUMBNAILER_PATH    TUMBLER_SERVICE_PATH_PREFIX "/Thumbnailer1"
+#define THUMBNAILER_PATH TUMBLER_SERVICE_PATH_PREFIX "/Thumbnailer1"
 #define THUMBNAILER_SERVICE TUMBLER_SERVICE_NAME_PREFIX ".Thumbnailer1"
-#define THUMBNAILER_IFACE   TUMBLER_SERVICE_NAME_PREFIX ".Thumbnailer1"
-
+#define THUMBNAILER_IFACE TUMBLER_SERVICE_NAME_PREFIX ".Thumbnailer1"
 
 
 
@@ -60,94 +57,108 @@ typedef struct _SchedulerIdleInfo SchedulerIdleInfo;
 
 
 
-static void tumbler_service_constructed        (GObject            *object);
-static void tumbler_service_finalize           (GObject            *object);
-static void tumbler_service_get_property       (GObject            *object,
-                                                guint               prop_id,
-                                                GValue             *value,
-                                                GParamSpec         *pspec);
-static void tumbler_service_set_property       (GObject            *object,
-                                                guint               prop_id,
-                                                const GValue       *value,
-                                                GParamSpec         *pspec);
-static gboolean tumbler_service_queue_cb        (TumblerExportedService  *skeleton,
-                                                 GDBusMethodInvocation   *invocation,
-                                                 const gchar *const      *uris,
-                                                 const gchar *const      *mime_hints,
-                                                 const gchar             *flavor_name,
-                                                 const gchar             *scheduler_name,
-                                                 guint                    handle_to_dequeue,
-                                                 TumblerService          *service);
-static gboolean tumbler_service_dequeue_cb      (TumblerExportedService  *skeleton,
-                                                 GDBusMethodInvocation   *invocation,
-                                                 guint                     handle,
-                                                 TumblerService          *service);
-static gboolean tumbler_service_get_schedulers_cb(TumblerExportedService  *skeleton,
-                                                  GDBusMethodInvocation   *invocation,
-                                                  TumblerService          *service);
-static gboolean tumbler_service_get_supported_cb(TumblerExportedService  *skeleton,
-                                                 GDBusMethodInvocation   *invocation,
-                                                 TumblerService          *service);
-static gboolean tumbler_service_get_flavors_cb  (TumblerExportedService  *skeleton,
-                                                 GDBusMethodInvocation   *invocation,
-                                                 TumblerService          *service);
-static void tumbler_service_scheduler_error    (TumblerScheduler   *scheduler,
-                                                guint32             handle,
-                                                const gchar *const *failed_uris,
-                                                GQuark              error_domain,
-                                                gint                error_code,
-                                                const gchar        *message,
-                                                const gchar        *origin,
-                                                TumblerService     *service);
-static void tumbler_service_scheduler_finished (TumblerScheduler   *scheduler,
-                                                guint32             handle,
-                                                const gchar        *origin,
-                                                TumblerService     *service);
-static void tumbler_service_scheduler_ready    (TumblerScheduler   *scheduler,
-                                                guint32             handle,
-                                                const gchar *const *uris,
-                                                const gchar        *origin,
-                                                TumblerService     *service);
-static void tumbler_service_scheduler_started  (TumblerScheduler   *scheduler,
-                                                guint32             handle,
-                                                const gchar        *origin,
-                                                TumblerService     *service);
-static void tumbler_service_pre_unmount        (TumblerService     *service,
-                                                GMount             *mount,
-                                                GVolumeMonitor     *monitor);
-static void scheduler_idle_info_free           (SchedulerIdleInfo  *info);
+static void
+tumbler_service_constructed (GObject *object);
+static void
+tumbler_service_finalize (GObject *object);
+static void
+tumbler_service_get_property (GObject *object,
+                              guint prop_id,
+                              GValue *value,
+                              GParamSpec *pspec);
+static void
+tumbler_service_set_property (GObject *object,
+                              guint prop_id,
+                              const GValue *value,
+                              GParamSpec *pspec);
+static gboolean
+tumbler_service_queue_cb (TumblerExportedService *skeleton,
+                          GDBusMethodInvocation *invocation,
+                          const gchar *const *uris,
+                          const gchar *const *mime_hints,
+                          const gchar *flavor_name,
+                          const gchar *scheduler_name,
+                          guint handle_to_dequeue,
+                          TumblerService *service);
+static gboolean
+tumbler_service_dequeue_cb (TumblerExportedService *skeleton,
+                            GDBusMethodInvocation *invocation,
+                            guint handle,
+                            TumblerService *service);
+static gboolean
+tumbler_service_get_schedulers_cb (TumblerExportedService *skeleton,
+                                   GDBusMethodInvocation *invocation,
+                                   TumblerService *service);
+static gboolean
+tumbler_service_get_supported_cb (TumblerExportedService *skeleton,
+                                  GDBusMethodInvocation *invocation,
+                                  TumblerService *service);
+static gboolean
+tumbler_service_get_flavors_cb (TumblerExportedService *skeleton,
+                                GDBusMethodInvocation *invocation,
+                                TumblerService *service);
+static void
+tumbler_service_scheduler_error (TumblerScheduler *scheduler,
+                                 guint32 handle,
+                                 const gchar *const *failed_uris,
+                                 GQuark error_domain,
+                                 gint error_code,
+                                 const gchar *message,
+                                 const gchar *origin,
+                                 TumblerService *service);
+static void
+tumbler_service_scheduler_finished (TumblerScheduler *scheduler,
+                                    guint32 handle,
+                                    const gchar *origin,
+                                    TumblerService *service);
+static void
+tumbler_service_scheduler_ready (TumblerScheduler *scheduler,
+                                 guint32 handle,
+                                 const gchar *const *uris,
+                                 const gchar *origin,
+                                 TumblerService *service);
+static void
+tumbler_service_scheduler_started (TumblerScheduler *scheduler,
+                                   guint32 handle,
+                                   const gchar *origin,
+                                   TumblerService *service);
+static void
+tumbler_service_pre_unmount (TumblerService *service,
+                             GMount *mount,
+                             GVolumeMonitor *monitor);
+static void
+scheduler_idle_info_free (SchedulerIdleInfo *info);
 
 
 
 struct _TumblerService
 {
-  TumblerComponent       __parent__;
+  TumblerComponent __parent__;
 
-  GDBusConnection        *connection;
+  GDBusConnection *connection;
   TumblerExportedService *skeleton;
-  gboolean                dbus_interface_exported;
-  
-  TumblerRegistry        *registry;
-  TUMBLER_MUTEX          (mutex);
-  GList                  *schedulers;
+  gboolean dbus_interface_exported;
 
-  GVolumeMonitor         *volume_monitor;
+  TumblerRegistry *registry;
+  TUMBLER_MUTEX (mutex);
+  GList *schedulers;
+
+  GVolumeMonitor *volume_monitor;
 };
 
 struct _SchedulerIdleInfo
 {
   TumblerScheduler *scheduler;
-  TumblerService   *service;
-  gchar           **uris;
-  gchar            *message;
-  gchar            *origin;
-  guint             handle;
-  gint              error_code;
+  TumblerService *service;
+  gchar **uris;
+  gchar *message;
+  gchar *origin;
+  guint handle;
+  gint error_code;
 };
 
 
 
-
 G_DEFINE_TYPE (TumblerService, tumbler_service, TUMBLER_TYPE_COMPONENT);
 
 
@@ -158,8 +169,8 @@ tumbler_service_class_init (TumblerServiceClass *klass)
   GObjectClass *gobject_class;
 
   gobject_class = G_OBJECT_CLASS (klass);
-  gobject_class->constructed = tumbler_service_constructed; 
-  gobject_class->finalize = tumbler_service_finalize; 
+  gobject_class->constructed = tumbler_service_constructed;
+  gobject_class->finalize = tumbler_service_finalize;
   gobject_class->get_property = tumbler_service_get_property;
   gobject_class->set_property = tumbler_service_set_property;
 
@@ -168,16 +179,14 @@ tumbler_service_class_init (TumblerServiceClass *klass)
                                                         "connection",
                                                         "connection",
                                                         G_TYPE_DBUS_CONNECTION,
-                                                        G_PARAM_READWRITE |
-                                                        G_PARAM_CONSTRUCT_ONLY));
+                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
   g_object_class_install_property (gobject_class, PROP_REGISTRY,
                                    g_param_spec_object ("registry",
                                                         "registry",
                                                         "registry",
                                                         TUMBLER_TYPE_REGISTRY,
-                                                        G_PARAM_READWRITE |
-                                                        G_PARAM_CONSTRUCT_ONLY));
+                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 
@@ -189,14 +198,14 @@ tumbler_service_init (TumblerService *service)
   service->schedulers = NULL;
 
   service->volume_monitor = g_volume_monitor_get ();
-  g_signal_connect_swapped (service->volume_monitor, "mount-pre-unmount", 
+  g_signal_connect_swapped (service->volume_monitor, "mount-pre-unmount",
                             G_CALLBACK (tumbler_service_pre_unmount), service);
 }
 
 
 
 static void
-tumbler_service_add_scheduler (TumblerService   *service, 
+tumbler_service_add_scheduler (TumblerService *service,
                                TumblerScheduler *scheduler)
 {
   /* add the scheduler to the list */
@@ -205,11 +214,11 @@ tumbler_service_add_scheduler (TumblerService   *service,
   /* connect to the scheduler signals */
   g_signal_connect (scheduler, "error",
                     G_CALLBACK (tumbler_service_scheduler_error), service);
-  g_signal_connect (scheduler, "finished", 
+  g_signal_connect (scheduler, "finished",
                     G_CALLBACK (tumbler_service_scheduler_finished), service);
-  g_signal_connect (scheduler, "ready", 
+  g_signal_connect (scheduler, "ready",
                     G_CALLBACK (tumbler_service_scheduler_ready), service);
-  g_signal_connect (scheduler, "started", 
+  g_signal_connect (scheduler, "started",
                     G_CALLBACK (tumbler_service_scheduler_started), service);
 }
 
@@ -217,7 +226,7 @@ tumbler_service_add_scheduler (TumblerService   *service,
 
 static void
 tumbler_service_remove_scheduler (TumblerScheduler *scheduler,
-                                  TumblerService   *service)
+                                  TumblerService *service)
 {
   g_return_if_fail (TUMBLER_IS_SCHEDULER (scheduler));
   g_return_if_fail (TUMBLER_IS_SERVICE (service));
@@ -233,9 +242,9 @@ static void
 tumbler_service_constructed (GObject *object)
 {
   TumblerScheduler *scheduler;
-  TumblerService   *service = TUMBLER_SERVICE (object);
-  GError           *error = NULL;
-  
+  TumblerService *service = TUMBLER_SERVICE (object);
+  GError *error = NULL;
+
   /* chain up to parent classes */
   if (G_OBJECT_CLASS (tumbler_service_parent_class)->constructed != NULL)
     (G_OBJECT_CLASS (tumbler_service_parent_class)->constructed) (object);
@@ -251,9 +260,9 @@ tumbler_service_constructed (GObject *object)
   g_object_unref (scheduler);
 
   /* everything is fine, install the generic thumbnailer D-Bus info */
-  service->skeleton = tumbler_exported_service_skeleton_new();
-  
-  g_dbus_interface_skeleton_export (G_DBUS_INTERFACE_SKELETON(service->skeleton),
+  service->skeleton = tumbler_exported_service_skeleton_new ();
+
+  g_dbus_interface_skeleton_export (G_DBUS_INTERFACE_SKELETON (service->skeleton),
                                     service->connection,
                                     THUMBNAILER_PATH,
                                     &error);
@@ -261,26 +270,26 @@ tumbler_service_constructed (GObject *object)
     {
       g_critical ("error exporting thumbnail service on session bus: %s", error->message);
       g_error_free (error);
-      service->dbus_interface_exported = FALSE; 
+      service->dbus_interface_exported = FALSE;
     }
   else
     {
       service->dbus_interface_exported = TRUE;
-      
+
       g_signal_connect (service->skeleton, "handle-queue",
-                        G_CALLBACK(tumbler_service_queue_cb), service);
-      
+                        G_CALLBACK (tumbler_service_queue_cb), service);
+
       g_signal_connect (service->skeleton, "handle-dequeue",
-                        G_CALLBACK(tumbler_service_dequeue_cb), service);
-      
+                        G_CALLBACK (tumbler_service_dequeue_cb), service);
+
       g_signal_connect (service->skeleton, "handle-get-supported",
-                        G_CALLBACK(tumbler_service_get_supported_cb), service);
-      
+                        G_CALLBACK (tumbler_service_get_supported_cb), service);
+
       g_signal_connect (service->skeleton, "handle-get-schedulers",
-                        G_CALLBACK(tumbler_service_get_schedulers_cb), service);
-      
+                        G_CALLBACK (tumbler_service_get_schedulers_cb), service);
+
       g_signal_connect (service->skeleton, "handle-get-flavors",
-                        G_CALLBACK(tumbler_service_get_flavors_cb), service);
+                        G_CALLBACK (tumbler_service_get_flavors_cb), service);
     }
 }
 
@@ -304,18 +313,16 @@ tumbler_service_finalize (GObject *object)
 
   /* release the reference on the thumbnailer registry */
   g_object_unref (service->registry);
-  
+
   /* Unexport from dbus */
   if (service->dbus_interface_exported)
-    g_dbus_interface_skeleton_unexport_from_connection 
-      (
-        G_DBUS_INTERFACE_SKELETON (service->skeleton),
-        service->connection
-      );
+    g_dbus_interface_skeleton_unexport_from_connection (
+      G_DBUS_INTERFACE_SKELETON (service->skeleton),
+      service->connection);
 
   /* release the Skeleton object */
   g_object_unref (service->skeleton);
-  
+
   /* release the D-Bus connection object */
   g_object_unref (service->connection);
 
@@ -327,9 +334,9 @@ tumbler_service_finalize (GObject *object)
 
 
 static void
-tumbler_service_get_property (GObject    *object,
-                              guint       prop_id,
-                              GValue     *value,
+tumbler_service_get_property (GObject *object,
+                              guint prop_id,
+                              GValue *value,
                               GParamSpec *pspec)
 {
   TumblerService *service = TUMBLER_SERVICE (object);
@@ -351,10 +358,10 @@ tumbler_service_get_property (GObject    *object,
 
 
 static void
-tumbler_service_set_property (GObject      *object,
-                              guint         prop_id,
+tumbler_service_set_property (GObject *object,
+                              guint prop_id,
                               const GValue *value,
-                              GParamSpec   *pspec)
+                              GParamSpec *pspec)
 {
   TumblerService *service = TUMBLER_SERVICE (object);
 
@@ -377,9 +384,9 @@ tumbler_service_set_property (GObject      *object,
 static gboolean
 tumbler_service_error_idle (gpointer user_data)
 {
-  TumblerCache      *cache;
+  TumblerCache *cache;
   SchedulerIdleInfo *info = user_data;
-  GVariant          *signal_variant;
+  GVariant *signal_variant;
 
   g_return_val_if_fail (info != NULL, FALSE);
   g_return_val_if_fail (TUMBLER_IS_SCHEDULER (info->scheduler), FALSE);
@@ -402,11 +409,11 @@ tumbler_service_error_idle (gpointer user_data)
 
   /* send the signal message over D-Bus */
   g_dbus_connection_emit_signal (info->service->connection,
-                                 info->origin, 
+                                 info->origin,
                                  THUMBNAILER_PATH,
                                  THUMBNAILER_IFACE,
                                  "Error",
-                                 signal_variant, 
+                                 signal_variant,
                                  NULL);
 
   scheduler_idle_info_free (info);
@@ -417,14 +424,14 @@ tumbler_service_error_idle (gpointer user_data)
 
 
 static void
-tumbler_service_scheduler_error (TumblerScheduler   *scheduler,
-                                 guint32             handle,
+tumbler_service_scheduler_error (TumblerScheduler *scheduler,
+                                 guint32 handle,
                                  const gchar *const *failed_uris,
-                                 GQuark              error_domain,
-                                 gint                error_code,
-                                 const gchar        *message,
-                                 const gchar        *origin,
-                                 TumblerService     *service)
+                                 GQuark error_domain,
+                                 gint error_code,
+                                 const gchar *message,
+                                 const gchar *origin,
+                                 TumblerService *service)
 {
   SchedulerIdleInfo *info;
 
@@ -443,7 +450,7 @@ tumbler_service_scheduler_error (TumblerScheduler   *scheduler,
 
   info->scheduler = g_object_ref (scheduler);
   info->handle = handle;
-  info->uris = g_strdupv ((gchar **)failed_uris);
+  info->uris = g_strdupv ((gchar **) failed_uris);
   info->origin = g_strdup (origin);
   info->service = g_object_ref (service);
   if (error_domain == TUMBLER_ERROR)
@@ -471,22 +478,22 @@ static gboolean
 tumbler_service_finished_idle (gpointer user_data)
 {
   SchedulerIdleInfo *info = user_data;
-  GVariant          *signal_variant;
+  GVariant *signal_variant;
 
   g_return_val_if_fail (info != NULL, FALSE);
   g_return_val_if_fail (info->origin != NULL && *info->origin != '\0', FALSE);
   g_return_val_if_fail (TUMBLER_IS_SERVICE (info->service), FALSE);
-  
+
   signal_variant = g_variant_new ("(u)",
                                   info->handle);
 
   /* send the signal message over D-Bus */
   g_dbus_connection_emit_signal (info->service->connection,
-                                 info->origin, 
+                                 info->origin,
                                  THUMBNAILER_PATH,
                                  THUMBNAILER_IFACE,
                                  "Finished",
-                                 signal_variant, 
+                                 signal_variant,
                                  NULL);
 
   /* allow the lifecycle manager to shut down the service again (unless there
@@ -502,9 +509,9 @@ tumbler_service_finished_idle (gpointer user_data)
 
 static void
 tumbler_service_scheduler_finished (TumblerScheduler *scheduler,
-                                    guint32           handle,
-                                    const gchar      *origin,
-                                    TumblerService   *service)
+                                    guint32 handle,
+                                    const gchar *origin,
+                                    TumblerService *service)
 {
   SchedulerIdleInfo *info;
 
@@ -526,11 +533,11 @@ tumbler_service_scheduler_finished (TumblerScheduler *scheduler,
 
 
 
-static gboolean 
+static gboolean
 tumbler_service_ready_idle (gpointer user_data)
 {
   SchedulerIdleInfo *info = user_data;
-  GVariant          *signal_variant;
+  GVariant *signal_variant;
 
   g_return_val_if_fail (info != NULL, FALSE);
   g_return_val_if_fail (TUMBLER_IS_SCHEDULER (info->scheduler), FALSE);
@@ -541,16 +548,16 @@ tumbler_service_ready_idle (gpointer user_data)
   signal_variant = g_variant_new ("(u^as)",
                                   info->handle,
                                   info->uris);
- 
+
   /* send the signal message over D-Bus */
   g_dbus_connection_emit_signal (info->service->connection,
-                                 info->origin, 
+                                 info->origin,
                                  THUMBNAILER_PATH,
                                  THUMBNAILER_IFACE,
                                  "Ready",
-                                 signal_variant, 
+                                 signal_variant,
                                  NULL);
-  
+
   scheduler_idle_info_free (info);
 
   return FALSE;
@@ -559,14 +566,14 @@ tumbler_service_ready_idle (gpointer user_data)
 
 
 static void
-tumbler_service_scheduler_ready (TumblerScheduler   *scheduler,
-                                 guint32             handle,
+tumbler_service_scheduler_ready (TumblerScheduler *scheduler,
+                                 guint32 handle,
                                  const gchar *const *uris,
-                                 const gchar        *origin,
-                                 TumblerService     *service)
+                                 const gchar *origin,
+                                 TumblerService *service)
 {
   SchedulerIdleInfo *info;
-  
+
   g_return_if_fail (TUMBLER_IS_SCHEDULER (scheduler));
   g_return_if_fail (origin != NULL && *origin != '\0');
   g_return_if_fail (uris != NULL && uris[0] != NULL && *uris[0] != '\0');
@@ -579,7 +586,7 @@ tumbler_service_scheduler_ready (TumblerScheduler   *scheduler,
 
   info->scheduler = g_object_ref (scheduler);
   info->handle = handle;
-  info->uris = g_strdupv ((gchar **)uris);
+  info->uris = g_strdupv ((gchar **) uris);
   info->origin = g_strdup (origin);
   info->service = g_object_ref (service);
 
@@ -592,24 +599,24 @@ static gboolean
 tumbler_service_started_idle (gpointer user_data)
 {
   SchedulerIdleInfo *info = user_data;
-  GVariant          *signal_variant;
-  
+  GVariant *signal_variant;
+
   g_return_val_if_fail (info != NULL, FALSE);
   g_return_val_if_fail (TUMBLER_IS_SCHEDULER (info->scheduler), FALSE);
   g_return_val_if_fail (info->origin != NULL && *info->origin != '\0', FALSE);
   g_return_val_if_fail (TUMBLER_IS_SERVICE (info->service), FALSE);
 
   signal_variant = g_variant_new ("(u)", info->handle);
- 
+
   /* send the signal message over D-Bus */
   g_dbus_connection_emit_signal (info->service->connection,
-                                 info->origin, 
+                                 info->origin,
                                  THUMBNAILER_PATH,
                                  THUMBNAILER_IFACE,
                                  "Started",
-                                 signal_variant, 
+                                 signal_variant,
                                  NULL);
-  
+
   scheduler_idle_info_free (info);
 
   return FALSE;
@@ -619,12 +626,12 @@ tumbler_service_started_idle (gpointer user_data)
 
 static void
 tumbler_service_scheduler_started (TumblerScheduler *scheduler,
-                                   guint32           handle,
-                                   const gchar      *origin,
-                                   TumblerService   *service)
+                                   guint32 handle,
+                                   const gchar *origin,
+                                   TumblerService *service)
 {
   SchedulerIdleInfo *info;
-  
+
   g_return_if_fail (TUMBLER_IS_SCHEDULER (scheduler));
   g_return_if_fail (origin != NULL && *origin != '\0');
   g_return_if_fail (TUMBLER_IS_SERVICE (service));
@@ -645,7 +652,7 @@ tumbler_service_scheduler_started (TumblerScheduler *scheduler,
 
 static void
 tumbler_service_pre_unmount (TumblerService *service,
-                             GMount         *mount,
+                             GMount *mount,
                              GVolumeMonitor *volume_monitor)
 {
   GList *iter;
@@ -684,41 +691,40 @@ scheduler_idle_info_free (SchedulerIdleInfo *info)
 
 
 TumblerService *
-tumbler_service_new (GDBusConnection         *connection,
+tumbler_service_new (GDBusConnection *connection,
                      TumblerLifecycleManager *lifecycle_manager,
-                     TumblerRegistry         *registry)
+                     TumblerRegistry *registry)
 {
-  return g_object_new (TUMBLER_TYPE_SERVICE, 
-                       "connection", connection, 
+  return g_object_new (TUMBLER_TYPE_SERVICE,
+                       "connection", connection,
                        "lifecycle-manager", lifecycle_manager,
-                       "registry", registry, 
+                       "registry", registry,
                        NULL);
 }
 
 
 
-
-static gboolean 
-tumbler_service_queue_cb (TumblerExportedService  *skeleton,
-                          GDBusMethodInvocation   *invocation,
-                          const gchar *const      *uris,
-                          const gchar *const      *mime_hints,
-                          const gchar             *flavor_name,
-                          const gchar             *scheduler_name,
-                          guint32                  handle_to_dequeue,
-                          TumblerService          *service)
+static gboolean
+tumbler_service_queue_cb (TumblerExportedService *skeleton,
+                          GDBusMethodInvocation *invocation,
+                          const gchar *const *uris,
+                          const gchar *const *mime_hints,
+                          const gchar *flavor_name,
+                          const gchar *scheduler_name,
+                          guint32 handle_to_dequeue,
+                          TumblerService *service)
 {
   TumblerSchedulerRequest *scheduler_request;
-  TumblerThumbnailFlavor  *flavor;
-  TumblerScheduler        *scheduler = NULL;
-  TumblerFileInfo        **infos;
-  TumblerCache            *cache;
-  GList                  **thumbnailers;
-  GList                   *iter;
-  gchar                   *name;
-  const gchar             *origin;
-  guint32                  handle;
-  guint                    length;
+  TumblerThumbnailFlavor *flavor;
+  TumblerScheduler *scheduler = NULL;
+  TumblerFileInfo **infos;
+  TumblerCache *cache;
+  GList **thumbnailers;
+  GList *iter;
+  gchar *name;
+  const gchar *origin;
+  guint32 handle;
+  guint length;
 
   g_dbus_async_return_val_if_fail (TUMBLER_IS_SERVICE (service), invocation, FALSE);
   g_dbus_async_return_val_if_fail (uris != NULL, invocation, FALSE);
@@ -748,8 +754,7 @@ tumbler_service_queue_cb (TumblerExportedService  *skeleton,
   origin = g_dbus_method_invocation_get_sender (invocation);
 
   /* allocate a scheduler request */
-  scheduler_request = tumbler_scheduler_request_new (infos, thumbnailers, 
-                                                     length, origin);
+  scheduler_request = tumbler_scheduler_request_new (infos, thumbnailers, length, origin);
 
   /* release the file info array */
   tumbler_file_info_array_free (infos);
@@ -764,7 +769,7 @@ tumbler_service_queue_cb (TumblerExportedService  *skeleton,
   /* iterate over all schedulers */
   for (iter = service->schedulers; iter != NULL; iter = iter->next)
     {
-      /* dequeue the request with the given dequeue handle, in case this 
+      /* dequeue the request with the given dequeue handle, in case this
        * scheduler is responsible for the given handle */
       if (handle_to_dequeue != 0)
         tumbler_scheduler_dequeue (TUMBLER_SCHEDULER (iter->data), handle_to_dequeue);
@@ -794,7 +799,7 @@ tumbler_service_queue_cb (TumblerExportedService  *skeleton,
 
       /* emit an error signal */
       tumbler_service_scheduler_error (scheduler, handle, uris, TUMBLER_ERROR,
-                                       TUMBLER_ERROR_UNSUPPORTED_FLAVOR, 
+                                       TUMBLER_ERROR_UNSUPPORTED_FLAVOR,
                                        TUMBLER_ERROR_MESSAGE_UNSUPPORTED_FLAVOR,
                                        scheduler_request->origin,
                                        service);
@@ -811,33 +816,33 @@ tumbler_service_queue_cb (TumblerExportedService  *skeleton,
       /* let the scheduler take it from here */
       tumbler_scheduler_push (scheduler, scheduler_request);
     }
-  
+
   /* free the thumbnailer array */
   tumbler_thumbnailer_array_free (thumbnailers, length);
 
   tumbler_mutex_unlock (service->mutex);
-  
-  tumbler_exported_service_complete_queue(skeleton, invocation, handle);
-  
+
+  tumbler_exported_service_complete_queue (skeleton, invocation, handle);
+
   /* try to keep tumbler alive */
   tumbler_component_keep_alive (TUMBLER_COMPONENT (service), NULL);
-    
+
   return TRUE;
 }
 
 
 
-static gboolean 
-tumbler_service_dequeue_cb (TumblerExportedService  *skeleton,
-                            GDBusMethodInvocation   *invocation,
-                            guint32                  handle,
-                            TumblerService          *service)
+static gboolean
+tumbler_service_dequeue_cb (TumblerExportedService *skeleton,
+                            GDBusMethodInvocation *invocation,
+                            guint32 handle,
+                            TumblerService *service)
 {
   GList *iter;
 
   tumbler_mutex_lock (service->mutex);
 
-  if (handle != 0) 
+  if (handle != 0)
     {
       g_debug ("Dequeuing files for job %d", handle);
 
@@ -852,24 +857,24 @@ tumbler_service_dequeue_cb (TumblerExportedService  *skeleton,
 
   tumbler_mutex_unlock (service->mutex);
 
-  tumbler_exported_service_complete_dequeue(skeleton, invocation);
-    
+  tumbler_exported_service_complete_dequeue (skeleton, invocation);
+
   /* keep tumbler alive */
   tumbler_component_keep_alive (TUMBLER_COMPONENT (service), NULL);
-  
+
   return TRUE;
 }
 
 
 
-static gboolean 
-tumbler_service_get_schedulers_cb (TumblerExportedService  *skeleton,
-                                   GDBusMethodInvocation   *invocation,
-                                   TumblerService          *service)
+static gboolean
+tumbler_service_get_schedulers_cb (TumblerExportedService *skeleton,
+                                   GDBusMethodInvocation *invocation,
+                                   TumblerService *service)
 {
   gchar **supported_schedulers;
-  GList  *iter;
-  guint   n = 0;
+  GList *iter;
+  guint n = 0;
 
   tumbler_mutex_lock (service->mutex);
 
@@ -882,7 +887,7 @@ tumbler_service_get_schedulers_cb (TumblerExportedService  *skeleton,
   /* append all supported scheduler names */
   for (iter = service->schedulers; iter != NULL; iter = iter->next)
     {
-      supported_schedulers[n++] = 
+      supported_schedulers[n++] =
         tumbler_scheduler_get_name (TUMBLER_SCHEDULER (iter->data));
     }
 
@@ -892,25 +897,25 @@ tumbler_service_get_schedulers_cb (TumblerExportedService  *skeleton,
   supported_schedulers[n] = NULL;
 
   /* return the scheduler array to the caller */
-  tumbler_exported_service_complete_get_schedulers (skeleton, 
+  tumbler_exported_service_complete_get_schedulers (skeleton,
                                                     invocation,
-                                                    (const char* const*)supported_schedulers);
+                                                    (const char *const *) supported_schedulers);
 
   /* free the array */
   g_strfreev (supported_schedulers);
 
   /* try to keep tumbler alive */
   tumbler_component_keep_alive (TUMBLER_COMPONENT (service), NULL);
-  
+
   return TRUE;
 }
 
 
 
-static gboolean 
-tumbler_service_get_supported_cb (TumblerExportedService  *skeleton,
-                                  GDBusMethodInvocation   *invocation,
-                                  TumblerService          *service)
+static gboolean
+tumbler_service_get_supported_cb (TumblerExportedService *skeleton,
+                                  GDBusMethodInvocation *invocation,
+                                  TumblerService *service)
 {
   const gchar *const *mime_types;
   const gchar *const *uri_schemes;
@@ -925,26 +930,26 @@ tumbler_service_get_supported_cb (TumblerExportedService  *skeleton,
   tumbler_mutex_unlock (service->mutex);
 
   /* return the arrays to the caller */
-  tumbler_exported_service_complete_get_supported(skeleton, invocation, uri_schemes, mime_types);
+  tumbler_exported_service_complete_get_supported (skeleton, invocation, uri_schemes, mime_types);
 
   /* try to keep tumbler alive */
   tumbler_component_keep_alive (TUMBLER_COMPONENT (service), NULL);
-  
+
   return TRUE;
 }
 
 
 
-static gboolean 
-tumbler_service_get_flavors_cb  (TumblerExportedService  *skeleton,
-                                 GDBusMethodInvocation   *invocation,
-                                 TumblerService          *service)
+static gboolean
+tumbler_service_get_flavors_cb (TumblerExportedService *skeleton,
+                                GDBusMethodInvocation *invocation,
+                                TumblerService *service)
 {
   TumblerCache *cache;
   const gchar **flavor_strings;
-  GList        *flavors;
-  GList        *iter;
-  guint         n;
+  GList *flavors;
+  GList *iter;
+  guint n;
 
   cache = tumbler_cache_get_default ();
 
@@ -956,9 +961,9 @@ tumbler_service_get_flavors_cb  (TumblerExportedService  *skeleton,
       for (iter = flavors, n = 0; iter != NULL; iter = iter->next, ++n)
         flavor_strings[n] = tumbler_thumbnail_flavor_get_name (iter->data);
       flavor_strings[n] = NULL;
-   
+
       tumbler_exported_service_complete_get_flavors (skeleton, invocation, flavor_strings);
-      
+
       g_free (flavor_strings);
       g_list_free_full (flavors, g_object_unref);
       g_object_unref (cache);
@@ -967,7 +972,7 @@ tumbler_service_get_flavors_cb  (TumblerExportedService  *skeleton,
     {
       flavor_strings = g_new0 (const gchar *, 1);
       flavor_strings[0] = NULL;
-      
+
       tumbler_exported_service_complete_get_flavors (skeleton, invocation, flavor_strings);
 
       g_free (flavor_strings);
@@ -981,8 +986,9 @@ tumbler_service_get_flavors_cb  (TumblerExportedService  *skeleton,
 
 
 
-gboolean tumbler_service_is_exported (TumblerService *service)
+gboolean
+tumbler_service_is_exported (TumblerService *service)
 {
-  g_return_val_if_fail (TUMBLER_IS_SERVICE(service), FALSE);
+  g_return_val_if_fail (TUMBLER_IS_SERVICE (service), FALSE);
   return service->dbus_interface_exported;
 }
